﻿#region License
/* Copyright 2004, 2013 James F. Bellinger
 * 
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 * 
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redestribute it
 * freely, subject to the following restrictions:
 * 
 * 1. The origin of this software must not be misrepresented; you must
 * not claim that you wrote the original software. If you use this software
 * in a product, an acknowledgement in the product documentation would be
 * appreciated but is not required.
 * 
 * 2. Altered source versions must be plainly marked as such, and must
 * not be misrepresented as being the original software.
 * 
 * 3. This notice may not be removed or altered from any source
 * distribution. */
#endregion

using System;

namespace Chatter.Plugins.Events
{
    /// <summary>
    /// Stores information about a user joining/leaving a channel.
    /// </summary>
    public class EntryEventArgs : EventArgs
    {
        /// <summary>
        /// Constructs an event for joining/leaving channels.
        /// </summary>
        /// <param name="entryType">Whether the user is joining, leaving, etc.</param>
        /// <param name="nickname">The nickname of the user.</param>
        /// <param name="channel">The channel the user is joining or leaving.</param>
        public EntryEventArgs(EntryType entryType, string nickname, string channel)
        {
            EntryType = entryType; Nickname = nickname; Channel = channel;
        }

        public string Channel
        {
            get;
            private set;
        }

        public EntryType EntryType
        {
            get;
            private set;
        }

        public string Nickname
        {
            get;
            private set;
        }
    }
}