#region License
/* Copyright 2004 James F. Bellinger
 * 
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 * 
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redestribute it
 * freely, subject to the following restrictions:
 * 
 * 1. The origin of this software must not be misrepresented; you must
 * not claim that you wrote the original software. If you use this software
 * in a product, an acknowledgement in the product documentation would be
 * appreciated but is not required.
 * 
 * 2. Altered source versions must be plainly marked as such, and must
 * not be misrepresented as being the original software.
 * 
 * 3. This notice may not be removed or altered from any source
 * distribution. */
#endregion

using System;
using System.Text;

namespace Chatter
{
	public class Filters
	{
		public static string ComputeElizabethan(string Text)
		{
			// This is kind of cheesy, and really doesn't give a
			// medieval 'feel'.

			return Text.Replace(" yours ", " thine ").
				Replace(" your ", " thy ").
				Replace(" you ", " thou ").
				Replace(" are ", " art ").
				Replace(" were ", " wert ").
				Replace(" is ", " doth be ").
				Replace(" was ", " didst be ");
		}

		public static string ComputeProperEnglish(string Text)
		{
			// This filter makes few changes, but these are some
			// pretty common shortcuts lazier typers seem to make. :)

			StringBuilder s = new StringBuilder(" " + Text + " ");

			s.Replace(" u ",   " you " );
			s.Replace(" r ",   " are " );
			s.Replace(" m ",   " am "  );
			s.Replace(" y ",   " why " );
			s.Replace(" wut ", " what ");
			s.Replace(" wat ", " what ");
			s.Replace(" teh ", " the " );

			if (s.Length > 0)
			{
				if (char.IsLower(s[0])) { s[0] = char.ToUpper(s[0]); }
			}

			return s.ToString().Trim();
		}

		public static string ComputeShorthand(string Text)
		{
			StringBuilder s = new StringBuilder();
			Random r = new Random(); bool filter = false;

			foreach (char ch in Text)
			{
				if (filter)
				{
					switch(ch)
					{
						case '`': s.Append('`'); goto case ' ';
						case ' ': filter = false; break;
						case 'p':
							// 'Positive' shortcut.
							switch(r.Next(0, 5))
							{
								case 0: s.Append("good "); break;
								case 1: s.Append("great "); break;
								case 2: s.Append("stupendous "); break;
								case 3: s.Append("wonderful "); break;
								case 4: s.Append("super "); break;
								case 5: s.Append("nifty "); break;
							}
							break;
						case 'n':
							// 'Negative' shortcut.
							switch(r.Next(0, 4))
							{
								case 0: s.Append("bad "); break;
								case 1: s.Append("terrible "); break;
								case 2: s.Append("horrible "); break;
								case 3: s.Append("tragic "); break;
								case 4: s.Append("unfortunate "); break;
							}
							break;
						case 'g':
							// 'Greeting' shortcut.
							switch(r.Next(0, 3))
							{
								case 0: s.Append("Greetings "); break;
								case 1: s.Append("Salutations "); break;
								case 2: s.Append("Hello "); break;
								case 3: s.Append("Hey "); break;
							}
							break;
						case ',':
						case '.': if (s.Length > 0) { s[s.Length - 1] = ch; } break;
					}
				}
				else
				{
					switch(ch)
					{
						case '`': filter = true; break;
						default : s.Append(ch); break;
					}
				}
			}

			return s.ToString();
		}
	}
}