#region License
/* Copyright 2004 James F. Bellinger
 * 
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 * 
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redestribute it
 * freely, subject to the following restrictions:
 * 
 * 1. The origin of this software must not be misrepresented; you must
 * not claim that you wrote the original software. If you use this software
 * in a product, an acknowledgement in the product documentation would be
 * appreciated but is not required.
 * 
 * 2. Altered source versions must be plainly marked as such, and must
 * not be misrepresented as being the original software.
 * 
 * 3. This notice may not be removed or altered from any source
 * distribution. */
#endregion

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace Chatter
{
	public class InputDialog : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.TextBox textMessage;
		private System.Windows.Forms.Label queryLabel;
		private System.ComponentModel.Container components = null;

        Func<string, bool> validateCallback;

		public static DialogResult QueryDialog(string Message,
			string Title, Func<string, bool> ValidateCallback, out string Text)
		{
			InputDialog form = new InputDialog();
            form.Text = Title; form.queryLabel.Text = Message; form.validateCallback = ValidateCallback;
  			DialogResult result = form.ShowDialog();

			Text = form.textMessage.Text; form.Dispose(); return result;
		}

		private InputDialog()
		{
			InitializeComponent();
		}

		protected override void Dispose(bool disposing )
		{
			if (disposing)
			{
				if (components != null)
				{
					components.Dispose();
				}
			}

			base.Dispose(disposing);
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.okButton = new System.Windows.Forms.Button();
            this.cancelButton = new System.Windows.Forms.Button();
            this.textMessage = new System.Windows.Forms.TextBox();
            this.queryLabel = new System.Windows.Forms.Label();
            this.SuspendLayout();
            // 
            // okButton
            // 
            this.okButton.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.okButton.Enabled = false;
            this.okButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.okButton.Location = new System.Drawing.Point(8, 64);
            this.okButton.Name = "okButton";
            this.okButton.Size = new System.Drawing.Size(72, 24);
            this.okButton.TabIndex = 1;
            this.okButton.Text = "OK";
            // 
            // cancelButton
            // 
            this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.cancelButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.cancelButton.Location = new System.Drawing.Point(160, 64);
            this.cancelButton.Name = "cancelButton";
            this.cancelButton.Size = new System.Drawing.Size(72, 24);
            this.cancelButton.TabIndex = 2;
            this.cancelButton.Text = "Cancel";
            // 
            // textMessage
            // 
            this.textMessage.Location = new System.Drawing.Point(8, 32);
            this.textMessage.Name = "textMessage";
            this.textMessage.Size = new System.Drawing.Size(224, 20);
            this.textMessage.TabIndex = 0;
            this.textMessage.TextChanged += new System.EventHandler(this.textMessage_TextChanged);
            // 
            // queryLabel
            // 
            this.queryLabel.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.queryLabel.Location = new System.Drawing.Point(8, 8);
            this.queryLabel.Name = "queryLabel";
            this.queryLabel.Size = new System.Drawing.Size(224, 16);
            this.queryLabel.TabIndex = 3;
            this.queryLabel.Text = "-";
            // 
            // InputDialog
            // 
            this.AcceptButton = this.okButton;
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.CancelButton = this.cancelButton;
            this.ClientSize = new System.Drawing.Size(240, 94);
            this.Controls.Add(this.queryLabel);
            this.Controls.Add(this.textMessage);
            this.Controls.Add(this.cancelButton);
            this.Controls.Add(this.okButton);
            this.MaximizeBox = false;
            this.MinimizeBox = false;
            this.Name = "InputDialog";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "-";
            this.Load += new System.EventHandler(this.InputDialog_Load);
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion

		private void InputDialog_Load(object sender, System.EventArgs e)
		{
		
		}

		private void textMessage_TextChanged(object sender, EventArgs e)
		{
            okButton.Enabled =
                textMessage.Text.Length > 0 && (validateCallback == null || validateCallback(textMessage.Text));
		}
	}
}
