#region License
/* Copyright 2004 James F. Bellinger
 * 
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 * 
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redestribute it
 * freely, subject to the following restrictions:
 * 
 * 1. The origin of this software must not be misrepresented; you must
 * not claim that you wrote the original software. If you use this software
 * in a product, an acknowledgement in the product documentation would be
 * appreciated but is not required.
 * 
 * 2. Altered source versions must be plainly marked as such, and must
 * not be misrepresented as being the original software.
 * 
 * 3. This notice may not be removed or altered from any source
 * distribution. */
#endregion

using System;
using System.Collections.Generic;
using System.Windows.Forms;
using Chatter.Logic;

namespace Chatter.Plugins
{
	class Manager: IDisposable
	{
		private class PluginOptionsLoader
		{
			Plugin plugin; ChatterMDI main;

			public PluginOptionsLoader(Plugin plugin, ChatterMDI main)
			{
				this.plugin = plugin; this.main = main;
			}

			public void ShowOptions(object o, System.EventArgs e)
			{
				((Client.IPluginOptions)plugin.Instance).ShowOptions(main);
			}
		}
		
        public class Plugin
		{
			public Plugin(PluginLoader.Entry plugin)
            {
                Info = plugin;

                try { Instance = Activator.CreateInstance(plugin.Type); }
                catch { }
            }

			public override string ToString()
	        {
                return Info.FriendlyName;
            }

            public PluginLoader.Entry Info;
			public object             Instance;
		}

		ChatterMDI main;
		List<Plugin> plugins;

		public List<Plugin> Plugins { get { return plugins; } }

		public Manager(ChatterMDI main)
		{
			this.main = main; plugins = new List<Plugin>();

            foreach (var plugin in PluginLoader.GetAllPlugins())
            {
                var item = new Plugin(plugin);

                if (item.Instance is Client.IPlugin)
                {
                    // Add to the listing and start the plugin!
                    plugins.Add(item);
                    ((Client.IPlugin)item.Instance).
                        StartPlugin(main);

                    if (item.Instance is Client.IPluginMenu ||
                        item.Instance is Client.IPluginOptions)
                    {
                        MenuItem m = new MenuItem(item.ToString());
                        main.mnuRobots.MenuItems.Add(m);

                        if (item.Instance is Client.IPluginOptions)
                        {
                            m.MenuItems.Add(new MenuItem
                                ("Options", new EventHandler
                                (new PluginOptionsLoader
                                (item, main).ShowOptions)));

                            if (item.Instance is Client.IPluginMenu)
                            {
                                m.MenuItems.Add(new MenuItem("-"));
                            }
                        }

                        if (item.Instance is Client.IPluginMenu)
                        {
                            ((Client.IPluginMenu)item.Instance).
                                ShowMenu(m);
                        }

                        main.mnuRobots.Enabled = true;
                    }
                }
                else
                {
                    Console.WriteLine("'{0}' does not implement IPlugin!", item.GetType());
                }
            }
		}

		public void Dispose()
		{
			if (plugins != null)
			{
				foreach (Plugin plugin in plugins)
				{
					object o = plugin.Instance; ((Client.IPlugin)o).StopPlugin();

					if (o is IDisposable) { ((IDisposable)o).Dispose(); }
				}

				plugins.Clear(); plugins = null;
			}
		}
	}
}